@@ -18,9 +18,9 @@ import json
 
 try:
     #compatibility in some remaining environments
-    import simplejson
+    import simplejson # type: ignore
 except ImportError:
-    import json as simplejson
+    import json as simplejson # type: ignore
 
 import random
 import string
@@ -40,6 +40,8 @@ import numpy as np
 import traceback
 from jsonschema import validate as validate_json
 
+import oda_api.token
+
 import logging
 
 logger = logging.getLogger("oda_api.api")
@@ -112,6 +114,7 @@ def safe_run(func):
         self = args[0]  # because it really is
 
         n_tries_left = self.n_max_tries
+        retry_sleep_s = self.retry_sleep_s
         while True:
             try:
                 return func(*args, **kwargs)
@@ -120,12 +123,14 @@ def safe_run(func):
                 raise
             except Unauthorized:
                 raise
-            except RequestNotUnderstood as e:
+            except RequestNotUnderstood:
                 raise
             except UnexpectedDispatcherStatusCode as e:
                 message = f'unexpected status code: {e}'
                 raise
-            except ConnectionError as e:
+            except (ConnectionError,
+                    requests.exceptions.ConnectionError,
+                    requests.exceptions.Timeout) as e:
                 message = ''
                 message += '\nunable to complete API call'
                 message += '\nin ' + str(func) + ' called with:'
@@ -143,8 +148,8 @@ def safe_run(func):
 
                 if n_tries_left > 0:
                     logger.warning("problem in API call, %i tries left:\n%s\n sleeping %i seconds until retry",
-                                    n_tries_left, message, self.retry_sleep_s)
-                    time.sleep(self.retry_sleep_s)
+                                   n_tries_left, message, retry_sleep_s)
+                    time.sleep(retry_sleep_s)
             
             raise RemoteException(
                 message=message
@@ -154,6 +159,11 @@ def safe_run(func):
 
 
 class DispatcherAPI:
+
+    # allowing token discovery by default changes the user interface in some cases, 
+    # but in desirable way
+    token_discovery_methods = None
+
     def __init__(self,
                  instrument='mock',
                  url=None,
@@ -168,7 +178,7 @@ class DispatcherAPI:
                  ):
 
         if url is None:
-            url = "https://www.astro.unige.ch/cdci/astrooda/dispatch-data"
+            url = "https://www.astro.unige.ch/mmoda/dispatch-data"
 
         if host is not None:
             logger.warning(
@@ -700,7 +710,7 @@ class DispatcherAPI:
                 if _s != '':
                     self.logger.info(_s)
             else:
-                self.logger.warning(
+                self.logger.debug(
                     'unable to dig list, instance not a dict by %s; object was %s', type(b), b)
 
                 if original_b != b:
@@ -841,10 +851,16 @@ class DispatcherAPI:
                         msg += '%s' % valid_names
                         msg += '\n'
                         msg += 'this will throw an error in a future version \n'
-                        msg += 'and might breack the current request!\n '
+                        msg += 'and might break the current request!\n '
                         msg += '----------------------------------------------------------------------------\n'
                         warnings.warn(msg)
 
+        if kwargs.get('token', None) is None and self.token_discovery_methods is not None:
+            discovered_token = oda_api.token.discover_token(self.token_discovery_methods)
+            if discovered_token is not None:
+                logger.info("discovered token in environment")
+                kwargs['token'] = discovered_token            
+
         # >
         self.request(kwargs)
 
@@ -882,7 +898,7 @@ class DispatcherAPI:
         return d
 
     @staticmethod
-    def set_api_code(query_dict, url="www.astro.unige.ch/cdci/astrooda/dispatch-data"):
+    def set_api_code(query_dict, url="www.astro.unige.ch/mmoda/dispatch-data"):
 
         _skip_list_ = ['job_id', 'query_status',
                        'session_id', 'use_resolver[local]', 'use_scws']
