@@ -4,6 +4,9 @@ import jwt
 import time
 import pytest
 
+import oda_api.api
+
+
 secret_key = 'secretkey_test'
 default_exp_time = int(time.time()) + 5000
 default_token_payload = dict(
@@ -56,12 +59,8 @@ def test_show_product(dispatcher_live_fixture, capsys):
     assert products._p_list[0].meta_data == meta_data_dic
 
 
-
-def test_oda_api_code(dispatcher_live_fixture):
-    import oda_api.api
-    disp = oda_api.api.DispatcherAPI(
-        url=dispatcher_live_fixture
-    )
+def test_oda_api_code(dispatcher_api):
+    disp = dispatcher_api
 
     disp.get_product(
         product_type="Dummy",
@@ -87,7 +86,7 @@ def test_oda_api_code(dispatcher_live_fixture):
     output_api_code = jdata_output['prod_dictionary']['api_code']
 
     expected_api_code = f'''from oda_api.api import DispatcherAPI
-disp=DispatcherAPI(url='PRODUCTS_URL', instrument='mock')
+disp=DispatcherAPI(url='PRODUCTS_URL/dispatch-data', instrument='mock')
 
 par_dict={{
     "instrument": "empty",
